@@ -32,6 +32,7 @@ import (
 	"k8s.io/kops/cloudmock/aws/mockec2"
 	gcemock "k8s.io/kops/cloudmock/gce"
 	"k8s.io/kops/cmd/kops/util"
+	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/commands"
 	"k8s.io/kops/pkg/featureflag"
 	"k8s.io/kops/pkg/testutils"
@@ -62,8 +63,8 @@ func (o *LifecycleTestOptions) AddDefaults() {
 	o.SrcDir = "../../tests/integration/update_cluster/" + o.SrcDir
 }
 
-// TestLifecycleMinimal runs the test on a minimum configuration, similar to kops create cluster minimal.example.com --zones us-west-1a
-func TestLifecycleMinimal(t *testing.T) {
+// TestLifecycleMinimalAWS runs the test on a minimum configuration, similar to kops create cluster minimal.example.com --zones us-west-1a
+func TestLifecycleMinimalAWS(t *testing.T) {
 	runLifecycleTestAWS(&LifecycleTestOptions{
 		t:      t,
 		SrcDir: "minimal",
@@ -111,6 +112,14 @@ func TestLifecyclePrivateKopeio(t *testing.T) {
 	})
 }
 
+// TestLifecycleIPv6 runs the test on a IPv6 topology
+func TestLifecycleIPv6(t *testing.T) {
+	runLifecycleTestAWS(&LifecycleTestOptions{
+		t:      t,
+		SrcDir: "minimal-ipv6",
+	})
+}
+
 // TestLifecycleSharedVPC runs the test on a shared VPC
 func TestLifecycleSharedVPC(t *testing.T) {
 	runLifecycleTestAWS(&LifecycleTestOptions{
@@ -188,34 +197,11 @@ func runLifecycleTest(h *testutils.IntegrationTestHarness, o *LifecycleTestOptio
 
 	inputYAML := "in-" + o.Version + ".yaml"
 
-	factoryOptions := &util.FactoryOptions{}
-	factoryOptions.RegistryPath = "memfs://tests"
-
-	factory := util.NewFactory(factoryOptions)
-
 	beforeResources := AllAWSResources(cloud)
 
-	{
-		options := &CreateOptions{}
-		options.Filenames = []string{path.Join(o.SrcDir, inputYAML)}
+	factory := newIntegrationTest(o.ClusterName, o.SrcDir).
+		setupCluster(t, inputYAML, ctx, stdout)
 
-		err := RunCreate(ctx, factory, &stdout, options)
-		if err != nil {
-			t.Fatalf("error running %q create: %v", inputYAML, err)
-		}
-	}
-
-	{
-		options := &CreateSecretPublickeyOptions{}
-		options.ClusterName = o.ClusterName
-		options.Name = "admin"
-		options.PublicKeyPath = path.Join(o.SrcDir, "id_rsa.pub")
-
-		err := RunCreateSecretPublicKey(ctx, factory, &stdout, options)
-		if err != nil {
-			t.Fatalf("error running %q create: %v", inputYAML, err)
-		}
-	}
 	updateEnsureNoChanges(ctx, t, factory, o.ClusterName, stdout)
 
 	// Overrides
@@ -235,12 +221,17 @@ func runLifecycleTest(h *testutils.IntegrationTestHarness, o *LifecycleTestOptio
 		}
 		for _, overrideBatch := range overrides {
 			t.Logf("overriding cluster values %v\n", overrideBatch)
-			setClusterOptions := &commands.SetClusterOptions{
-				Fields:      overrideBatch,
-				ClusterName: o.ClusterName,
+			instanceGroups, err := commands.ReadAllInstanceGroups(ctx, clientset, cluster)
+			if err != nil {
+				t.Fatalf("error reading instance groups: %v", err)
 			}
-			if err := commands.RunSetCluster(ctx, factory, nil, nil, setClusterOptions); err != nil {
-				t.Fatalf("error applying overrides: %v", err)
+
+			if err := commands.SetClusterFields(overrideBatch, cluster); err != nil {
+				t.Fatalf("error setting cluster fields: %v", err)
+			}
+
+			if err := commands.UpdateCluster(ctx, clientset, cluster, instanceGroups); err != nil {
+				t.Fatalf("error updating cluster: %v", err)
 			}
 			updateEnsureNoChanges(ctx, t, factory, o.ClusterName, stdout)
 		}
@@ -258,14 +249,29 @@ func runLifecycleTest(h *testutils.IntegrationTestHarness, o *LifecycleTestOptio
 
 			for _, overrideBatch := range overrides {
 				t.Logf("overriding instance group values (%v) %v\n", ig.Name, overrideBatch)
-				setIGOptions := &commands.SetInstanceGroupOptions{
-					Fields:            overrideBatch,
-					ClusterName:       o.ClusterName,
-					InstanceGroupName: ig.Name,
+				instanceGroups, err := commands.ReadAllInstanceGroups(ctx, clientset, cluster)
+				if err != nil {
+					t.Fatalf("error reading instance groups: %v", err)
 				}
-				if err := commands.RunSetInstancegroup(ctx, factory, nil, nil, setIGOptions); err != nil {
+				var instanceGroupToUpdate *kops.InstanceGroup
+				for _, instanceGroup := range instanceGroups {
+					if instanceGroup.GetName() == ig.Name {
+						instanceGroupToUpdate = instanceGroup
+					}
+				}
+				if instanceGroupToUpdate == nil {
+					t.Fatalf("unable to find instance group with name %q", ig.Name)
+				}
+
+				err = commands.SetInstancegroupFields(overrideBatch, instanceGroupToUpdate)
+				if err != nil {
 					t.Fatalf("error applying overrides: %v", err)
 				}
+
+				err = commands.UpdateInstanceGroup(ctx, clientset, cluster, instanceGroups, instanceGroupToUpdate)
+				if err != nil {
+					t.Fatalf("error updating instance groups: %v", err)
+				}
 				updateEnsureNoChanges(ctx, t, factory, o.ClusterName, stdout)
 			}
 		}
@@ -430,32 +436,8 @@ func runLifecycleTestOpenstack(o *LifecycleTestOptions) {
 
 	inputYAML := "in-" + o.Version + ".yaml"
 
-	factoryOptions := &util.FactoryOptions{}
-	factoryOptions.RegistryPath = "memfs://tests"
-
-	factory := util.NewFactory(factoryOptions)
-
-	{
-		options := &CreateOptions{}
-		options.Filenames = []string{path.Join(o.SrcDir, inputYAML)}
-
-		err := RunCreate(ctx, factory, &stdout, options)
-		if err != nil {
-			t.Fatalf("error running %q create: %v", inputYAML, err)
-		}
-	}
-
-	{
-		options := &CreateSecretPublickeyOptions{}
-		options.ClusterName = o.ClusterName
-		options.Name = "admin"
-		options.PublicKeyPath = path.Join(o.SrcDir, "id_rsa.pub")
-
-		err := RunCreateSecretPublicKey(ctx, factory, &stdout, options)
-		if err != nil {
-			t.Fatalf("error running %q create: %v", inputYAML, err)
-		}
-	}
+	factory := newIntegrationTest(o.ClusterName, o.SrcDir).
+		setupCluster(t, inputYAML, ctx, stdout)
 
 	updateEnsureNoChanges(ctx, t, factory, o.ClusterName, stdout)
 
@@ -508,31 +490,8 @@ func runLifecycleTestGCE(o *LifecycleTestOptions) {
 	var stdout bytes.Buffer
 	inputYAML := "in-" + o.Version + ".yaml"
 
-	factory := util.NewFactory(&util.FactoryOptions{
-		RegistryPath: "memfs://tests",
-	})
-
-	{
-		options := &CreateOptions{}
-		options.Filenames = []string{path.Join(o.SrcDir, inputYAML)}
-
-		err := RunCreate(ctx, factory, &stdout, options)
-		if err != nil {
-			t.Fatalf("error running %q create: %v", inputYAML, err)
-		}
-	}
-
-	{
-		options := &CreateSecretPublickeyOptions{}
-		options.ClusterName = o.ClusterName
-		options.Name = "admin"
-		options.PublicKeyPath = path.Join(o.SrcDir, "id_rsa.pub")
-
-		err := RunCreateSecretPublicKey(ctx, factory, &stdout, options)
-		if err != nil {
-			t.Fatalf("error running %q create: %v", inputYAML, err)
-		}
-	}
+	factory := newIntegrationTest(o.ClusterName, o.SrcDir).
+		setupCluster(t, inputYAML, ctx, stdout)
 
 	updateEnsureNoChanges(ctx, t, factory, o.ClusterName, stdout)
 
@@ -565,8 +524,9 @@ func updateEnsureNoChanges(ctx context.Context, t *testing.T, factory *util.Fact
 
 	// We don't test it here, and it adds a dependency on kubectl
 	options.CreateKubecfg = false
+	options.ClusterName = clusterName
 
-	_, err := RunUpdateCluster(ctx, factory, clusterName, &stdout, options)
+	_, err := RunUpdateCluster(ctx, factory, &stdout, options)
 	if err != nil {
 		t.Fatalf("error running update cluster %q: %v", clusterName, err)
 	}
@@ -580,8 +540,9 @@ func updateEnsureNoChanges(ctx context.Context, t *testing.T, factory *util.Fact
 
 	// We don't test it here, and it adds a dependency on kubectl
 	options.CreateKubecfg = false
+	options.ClusterName = clusterName
 
-	results, err := RunUpdateCluster(ctx, factory, clusterName, &stdout, options)
+	results, err := RunUpdateCluster(ctx, factory, &stdout, options)
 	if err != nil {
 		t.Fatalf("error running update cluster %q: %v", clusterName, err)
 	}
