@@ -136,7 +136,7 @@ func (c *NodeupModelContext) EnsureDirectory(path string) error {
 	st, err := os.Stat(path)
 	if err != nil {
 		if os.IsNotExist(err) {
-			return os.MkdirAll(path, 0755)
+			return os.MkdirAll(path, 0o755)
 		}
 
 		return err
