@@ -105,6 +105,18 @@ func TestDockerBuilder_BuildFlags(t *testing.T) {
 			kops.DockerConfig{InsecureRegistries: []string{"registry1", "registry2"}},
 			"--insecure-registry=registry1 --insecure-registry=registry2",
 		},
+		{
+			kops.DockerConfig{DNS: []string{}},
+			"",
+		},
+		{
+			kops.DockerConfig{DNS: []string{"8.8.4.4"}},
+			"--dns=8.8.4.4",
+		},
+		{
+			kops.DockerConfig{DNS: []string{"8.8.4.4", "8.8.8.8"}},
+			"--dns=8.8.4.4 --dns=8.8.8.8",
+		},
 	}
 
 	for _, g := range grid {
