@@ -39,16 +39,13 @@ type NetworkingSpec struct {
 
 // ClassicNetworkingSpec is the specification of classic networking mode, integrated into kubernetes.
 // Support been removed since Kubernetes 1.4.
-type ClassicNetworkingSpec struct {
-}
+type ClassicNetworkingSpec struct{}
 
 // KubenetNetworkingSpec is the specification for kubenet networking, largely integrated but intended to replace classic
-type KubenetNetworkingSpec struct {
-}
+type KubenetNetworkingSpec struct{}
 
 // ExternalNetworkingSpec is the specification for networking that is implemented by a user-provided Daemonset that uses the Kubenet kubelet networking plugin.
-type ExternalNetworkingSpec struct {
-}
+type ExternalNetworkingSpec struct{}
 
 // CNINetworkingSpec is the specification for networking that is implemented by a user-provided Daemonset, which uses the CNI kubelet networking plugin.
 type CNINetworkingSpec struct {
@@ -56,8 +53,7 @@ type CNINetworkingSpec struct {
 }
 
 // KopeioNetworkingSpec declares that we want Kopeio networking
-type KopeioNetworkingSpec struct {
-}
+type KopeioNetworkingSpec struct{}
 
 // WeaveNetworkingSpec declares that we want Weave networking
 type WeaveNetworkingSpec struct {
@@ -242,8 +238,7 @@ type CanalNetworkingSpec struct {
 }
 
 // KuberouterNetworkingSpec declares that we want Kube-router networking
-type KuberouterNetworkingSpec struct {
-}
+type KuberouterNetworkingSpec struct{}
 
 // RomanaNetworkingSpec declares that we want Romana networking
 // Romana is deprecated as of kOps 1.18 and removed as of kOps 1.19.
@@ -268,8 +263,10 @@ const CiliumIpamEni = "eni"
 
 type CiliumEncryptionType string
 
-const CiliumEncryptionTypeIPSec CiliumEncryptionType = "ipsec"
-const CiliumEncryptionTypeWireguard CiliumEncryptionType = "wireguard"
+const (
+	CiliumEncryptionTypeIPSec     CiliumEncryptionType = "ipsec"
+	CiliumEncryptionTypeWireguard CiliumEncryptionType = "wireguard"
+)
 
 // CiliumNetworkingSpec declares that we want Cilium networking
 type CiliumNetworkingSpec struct {
@@ -579,5 +576,4 @@ type LyftVPCNetworkingSpec struct {
 }
 
 // GCENetworkingSpec is the specification of GCE's native networking mode, using IP aliases
-type GCENetworkingSpec struct {
-}
+type GCENetworkingSpec struct{}
