@@ -576,11 +576,9 @@ func (b *PolicyBuilder) buildS3WriteStatements(p *Policy, iamS3Path string) {
 			fmt.Sprintf("arn:%v:s3:::%v/*", b.Partition, iamS3Path),
 		),
 	})
-
 }
 
 func (b *PolicyBuilder) buildS3GetStatements(p *Policy, iamS3Path string) error {
-
 	resources, err := ReadableStatePaths(b.Cluster, b.Role)
 	if err != nil {
 		return err
@@ -682,8 +680,10 @@ type PolicyResource struct {
 	DNSZone *awstasks.DNSZone
 }
 
-var _ fi.Resource = &PolicyResource{}
-var _ fi.HasDependencies = &PolicyResource{}
+var (
+	_ fi.Resource        = &PolicyResource{}
+	_ fi.HasDependencies = &PolicyResource{}
+)
 
 // GetDependencies adds the DNSZone task to the list of dependencies if set
 func (b *PolicyResource) GetDependencies(tasks map[string]fi.Task) []fi.Task {
@@ -788,7 +788,6 @@ func addEtcdManagerPermissions(p *Policy) {
 			},
 		},
 	)
-
 }
 
 func AddLegacyCCMPermissions(p *Policy) {
@@ -919,7 +918,6 @@ func AddAWSLoadbalancerControllerPermissions(p *Policy) {
 		"elasticloadbalancing:AddTags",
 		"elasticloadbalancing:RemoveTags",
 	)
-
 }
 
 func AddClusterAutoscalerPermissions(p *Policy) {
@@ -937,7 +935,6 @@ func AddClusterAutoscalerPermissions(p *Policy) {
 
 // AddAWSEBSCSIDriverPermissions appens policy statements that the AWS EBS CSI Driver needs to operate.
 func AddAWSEBSCSIDriverPermissions(p *Policy, partition string, appendSnapshotPermissions bool) {
-
 	if appendSnapshotPermissions {
 		addSnapshotPersmissions(p)
 	}
@@ -1146,7 +1143,8 @@ func addAmazonVPCCNIPermissions(p *Policy, partition string) {
 			}),
 			Resource: stringorslice.Slice([]string{
 				strings.Join([]string{"arn:", partition, ":ec2:*:*:network-interface/*"}, ""),
-			})},
+			}),
+		},
 	)
 }
 
@@ -1162,5 +1160,4 @@ func AddNodeTerminationHandlerSQSPermissions(p *Policy) {
 	p.clusterTaggedAction.Insert(
 		"autoscaling:CompleteLifecycleAction",
 	)
-
 }
